import matplotlib.pyplot as plt
import pandas as pd
import numpy as np
from tensorflow.keras import layers
from tensorflow.keras import models
from tensorflow.keras.preprocessing import image
from tensorflow.keras.utils import to_categorical
from tensorflow.keras import optimizers
from tensorflow.keras.layers import LSTM

def read_split_reshape(df,target_label,avoided_labels,window):
	for l in avoided_labels:
		df.pop(l)

	y_ = df.pop(target_label).to_numpy()
	# reshape input for RNN into [samples, timesteps, features]
	X_=df.to_numpy().reshape(int(len(df)/WINDOW), WINDOW,len(df.columns))
	y_ =y_[list(np.arange(WINDOW-1,len(df)+WINDOW-1,WINDOW))]
	return X_,y_

train_data = pd.read_csv("training.txt",nrows=8100)
val_data = pd.read_csv("validation.txt",nrows=2660)
test_data = pd.read_csv("test.txt",nrows=9750)
ax = train_data.plot(subplots=True, layout=(7,1))
plt.show()


WINDOW = 10

X_train, y_train = read_split_reshape(train_data,"Occupancy",["date"],WINDOW)
X_val, y_val = read_split_reshape(val_data,"Occupancy",["date"],WINDOW)
X_test,y_test = read_split_reshape(test_data,"Occupancy",["date"],WINDOW)

print(X_train.shape)
print(X_val.shape)
print(y_train.shape)
print("\n\n")
#y_train = to_categorical(y_train)
#y_val = to_categorical(y_val)

model = models.Sequential()

#Implement your network as you prefer and requested in the exercise
model = models.Sequential() #initialize the neural network
model.add(LSTM(100, activation='relu', input_shape=(WINDOW,5)))
model.add(layers.Dense(1, activation='sigmoid'))
model.summary() 

model.compile(loss='binary_crossentropy',optimizer="adam",metrics=['acc'])
history = model.fit(X_train, y_train, epochs=30, batch_size=32, validation_data=(X_val, y_val))

test_loss,test_acc = model.evaluate(X_test,y_test)
print(test_acc)

# Plot loss (y axis) and epochs (x axis) for training set and validation set
plt.figure()
plt.xlabel('Epoch')
plt.ylabel('Loss')
plt.plot(history.epoch, np.array(history.history['loss']),label='Train loss')
plt.plot(history.epoch, np.array(history.history['val_loss']),label = 'Val loss')
plt.legend()
plt.show()



